==> foundation-2.6.1.tgz: package/SocialGooglePlus/SocialGooglePlus.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const SocialGooglePlus = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M25.194 51.591c1.757 1.379 3.766 2.068 6.026 2.068 2.855-.105 5.234-1.131 7.138-3.076.918-1.377 1.508-2.791 1.77-4.24.157-1.447.236-2.668.236-3.658 0-4.276-1.094-8.588-3.281-12.936-1.026-2.084-2.376-3.781-4.051-5.09-1.71-1.236-3.675-1.891-5.897-1.961-2.939.07-5.384 1.256-7.331 3.553-1.644 2.404-2.43 5.09-2.358 8.057 0 3.924 1.147 8.008 3.444 12.248a16.741 16.741 0 004.304 5.035zm6.587 16.459a23.029 23.029 0 01-2.091-3.299c-.714-1.133-1.07-2.5-1.07-4.096 0-.957.135-1.756.407-2.395a366.3 366.3 0 01.663-1.861 30.289 30.289 0 01-3.485.213c-5.169-.062-9.237-1.527-12.205-4.388v19.338a33.422 33.422 0 018.241-2.561c3.829-.564 7.009-.881 9.54-.951zm2.959 3.064a23.873 23.873 0 00-2.435-.107c-.553-.07-1.969 0-4.248.213a46.623 46.623 0 00-6.89 1.533c-.553.213-1.33.529-2.331.953-1.002.459-2.021 1.111-3.056 1.959A10.843 10.843 0 0014 77.69v2.949a5.018 5.018 0 005.013 5.014h27.326c.001-.068.005-.133.005-.199 0-2.752-.899-5.15-2.694-7.197-1.9-1.94-4.869-4.32-8.91-7.143z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M80.986 14.347H19.013A5.016 5.016 0 0014 19.361v6.723c.316-.336.643-.67.985-1 3.083-2.539 6.288-4.195 9.612-4.973 3.29-.67 6.375-1.004 9.253-1.004h21.692l-6.699 3.91h-6.689c.681.422 1.448 1.041 2.299 1.852.817.846 1.618 1.887 2.401 3.121.749 1.164 1.413 2.539 1.992 4.127.476 1.586.715 3.44.715 5.555-.064 3.881-.921 6.984-2.569 9.312a29.44 29.44 0 01-2.569 3.121 102.307 102.307 0 01-3.199 2.91 15.086 15.086 0 00-1.793 2.275c-.646.881-.97 1.904-.97 3.068 0 1.129.332 2.062.994 2.803a21.86 21.86 0 001.641 1.854l3.68 3.016a36.958 36.958 0 016.016 6.189c1.625 2.293 2.47 5.291 2.536 8.994 0 1.531-.198 3.01-.592 4.439h28.25A5.018 5.018 0 0086 80.639V19.36a5.017 5.017 0 00-5.014-5.013zm3.945 22.117H73.549v11.383h-5.514V36.464H56.653V30.95h11.382V19.569h5.514V30.95h11.382v5.514z"
  }));
});
SocialGooglePlus.displayName = 'SocialGooglePlus';
export const SocialGooglePlusDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/SocialGooglePlus/SocialGooglePlus.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var SocialGooglePlus = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M25.194 51.591c1.757 1.379 3.766 2.068 6.026 2.068 2.855-.105 5.234-1.131 7.138-3.076.918-1.377 1.508-2.791 1.77-4.24.157-1.447.236-2.668.236-3.658 0-4.276-1.094-8.588-3.281-12.936-1.026-2.084-2.376-3.781-4.051-5.09-1.71-1.236-3.675-1.891-5.897-1.961-2.939.07-5.384 1.256-7.331 3.553-1.644 2.404-2.43 5.09-2.358 8.057 0 3.924 1.147 8.008 3.444 12.248a16.741 16.741 0 004.304 5.035zm6.587 16.459a23.029 23.029 0 01-2.091-3.299c-.714-1.133-1.07-2.5-1.07-4.096 0-.957.135-1.756.407-2.395a366.3 366.3 0 01.663-1.861 30.289 30.289 0 01-3.485.213c-5.169-.062-9.237-1.527-12.205-4.388v19.338a33.422 33.422 0 018.241-2.561c3.829-.564 7.009-.881 9.54-.951zm2.959 3.064a23.873 23.873 0 00-2.435-.107c-.553-.07-1.969 0-4.248.213a46.623 46.623 0 00-6.89 1.533c-.553.213-1.33.529-2.331.953-1.002.459-2.021 1.111-3.056 1.959A10.843 10.843 0 0014 77.69v2.949a5.018 5.018 0 005.013 5.014h27.326c.001-.068.005-.133.005-.199 0-2.752-.899-5.15-2.694-7.197-1.9-1.94-4.869-4.32-8.91-7.143z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M80.986 14.347H19.013A5.016 5.016 0 0014 19.361v6.723c.316-.336.643-.67.985-1 3.083-2.539 6.288-4.195 9.612-4.973 3.29-.67 6.375-1.004 9.253-1.004h21.692l-6.699 3.91h-6.689c.681.422 1.448 1.041 2.299 1.852.817.846 1.618 1.887 2.401 3.121.749 1.164 1.413 2.539 1.992 4.127.476 1.586.715 3.44.715 5.555-.064 3.881-.921 6.984-2.569 9.312a29.44 29.44 0 01-2.569 3.121 102.307 102.307 0 01-3.199 2.91 15.086 15.086 0 00-1.793 2.275c-.646.881-.97 1.904-.97 3.068 0 1.129.332 2.062.994 2.803a21.86 21.86 0 001.641 1.854l3.68 3.016a36.958 36.958 0 016.016 6.189c1.625 2.293 2.47 5.291 2.536 8.994 0 1.531-.198 3.01-.592 4.439h28.25A5.018 5.018 0 0086 80.639V19.36a5.017 5.017 0 00-5.014-5.013zm3.945 22.117H73.549v11.383h-5.514V36.464H56.653V30.95h11.382V19.569h5.514V30.95h11.382v5.514z"
  }));
});
SocialGooglePlus.displayName = 'SocialGooglePlus';
export var SocialGooglePlusDimensions = {
  height: 100,
  width: 100
};
